#!/bin/bash

#   FILE: mkboot.sh -- Makes a boot floppy image.
# AUTHOR: W. Michael Petullo <burn_baby_burn@flyn.org>
#   DATE: 21 Aug 1999
#
# Copyright (c) 1999 W. Michael Petullo <burn_baby_burn@flyn.org>
# All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

. /etc/burn_baby_burn/bbb_functions

if ! configured; then
	print_message stderr "No config found in /etc or ~"
	exit 1
fi

DISK_IMG=`mktemp /tmp/mkboot_disk_image.XXXXXXX`
MNT_PT=`mktemp -u /tmp/mkboot_mnt_pt.XXXXXXX`
mkdir $MNT_PT || ( echo Could not create $MNT_PT; exit 1 )
dd if=/dev/zero of=$DISK_IMG bs=1024 count=1440
echo y | mke2fs $DISK_IMG
mount -o loop -t ext2 $DISK_IMG $MNT_PT
rm -rf $MNT_PT/lost+found
mkdir {$MNT_PT/dev,$MNT_PT/boot,$MNT_PT/etc}
mknod_from_path /dev/null $MNT_PT/dev/null
mknod_from_path /dev/loop0 $MNT_PT/dev/loop0
mknod_from_path $FLOPPY_DEV $MNT_PT/$FLOPPY_DEV
mknod_from_path $CD_DEV $MNT_PT/$CD_DEV
mknod_from_path $ROOT_DEV $MNT_PT/$ROOT_DEV
cp -f $KERNEL $KERNEL_OLD $BOOT_SECTOR $MNT_PT/boot
new $MNT_PT/etc/lilo.conf lilo.burn_baby_burn
lilo -v -c -r $MNT_PT
cp $DISK_IMG /$BOOT_IMG
umount $MNT_PT
rm -f $DISK_IMG
rmdir $MNT_PT
